.. _release-0-4-2:

0.4.2
=====

Bokeh ``0.4.2`` (Mar 2014) is a minor release:

* Improved MPL interface, PolyCollection plus examples
* Extensive tutorial with exercises and solutions
* %bokeh magic for IPython notebook
* InMemory storage backend for bokeh-server (usable without Redis)
